==> service_client-0.0.4-20220215.030001-26-sources.jar: com/northpool/service/config/style/style/style/Point.java <==
package com.northpool.service.config.style.style.style;

public class Point {
    //点底图通用样式
    String type; //专题类型
    String labelType;//专题类型描述
    String texture;//散点符号

    //大部分样式包含的属性
    Double defaultRadius; //默认半径
    String fillColor;//散点填充颜色
    Integer fillAlpha;//散点透明度
    String strokeColor;//边框颜色
    Integer strokeAlpha;//边框透明度
    String field;//字段
    Integer maxWeight;//最大权重值
    Integer radius;// 用户输入半径
    String[] colorArr;//色带值


    //散点图包含的属性
    String fillType; //散点还是符号，区分类型
    Integer circleR;//散点半径
    Integer imageWidth;//符号宽
    Integer imageHeight;//符号高
    Integer originAngle;//旋转角度
    Integer ratoteField;//旋转字段


    //气泡图独有的属性
    Integer numMin;//最小范围
    Integer numMax;//最大范围
    Integer radiusMin;//最小半径
    Integer radiusMax;//最大半径
    Integer bubbleStrokeWidth;//边框宽

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getLabelType() {
        return labelType;
    }

    public void setLabelType(String labelType) {
        this.labelType = labelType;
    }

    public String getTexture() {
        return texture;
    }

    public void setTexture(String texture) {
        this.texture = texture;
    }

    public Double getDefaultRadius() {
        return defaultRadius;
    }

    public void setDefaultRadius(Double defaultRadius) {
        this.defaultRadius = defaultRadius;
    }

    public String getFillColor() {
        return fillColor;
    }

    public void setFillColor(String fillColor) {
        this.fillColor = fillColor;
    }

    public Integer getFillAlpha() {
        return fillAlpha;
    }

    public void setFillAlpha(Integer fillAlpha) {
        this.fillAlpha = fillAlpha;
    }

    public String getStrokeColor() {
        return strokeColor;
    }

    public void setStrokeColor(String strokeColor) {
        this.strokeColor = strokeColor;
    }

    public Integer getStrokeAlpha() {
        return strokeAlpha;
    }

    public void setStrokeAlpha(Integer strokeAlpha) {
        this.strokeAlpha = strokeAlpha;
    }

    public String getField() {
        return field;
    }

    public void setField(String field) {
        this.field = field;
    }

    public Integer getMaxWeight() {
        return maxWeight;
    }

    public void setMaxWeight(Integer maxWeight) {
        this.maxWeight = maxWeight;
    }

    public Integer getRadius() {
        return radius;
    }

    public void setRadius(Integer radius) {
        this.radius = radius;
    }


    public String[] getColorArr() {
        return colorArr;
    }

    public void setColorArr(String[] colorArr) {
        this.colorArr = colorArr;
    }

    public String getFillType() {
        return fillType;
    }

    public void setFillType(String fillType) {
        this.fillType = fillType;
    }

    public Integer getCircleR() {
        return circleR;
    }

    public void setCircleR(Integer circleR) {
        this.circleR = circleR;
    }

    public Integer getImageWidth() {
        return imageWidth;
    }

    public void setImageWidth(Integer imageWidth) {
        this.imageWidth = imageWidth;
    }

    public Integer getImageHeight() {
        return imageHeight;
    }

    public void setImageHeight(Integer imageHeight) {
        this.imageHeight = imageHeight;
    }

    public Integer getOriginAngle() {
        return originAngle;
    }

    public void setOriginAngle(Integer originAngle) {
        this.originAngle = originAngle;
    }

    public Integer getRatoteField() {
        return ratoteField;
    }

    public void setRatoteField(Integer ratoteField) {
        this.ratoteField = ratoteField;
    }

    public Integer getNumMin() {
        return numMin;
    }

    public void setNumMin(Integer numMin) {
        this.numMin = numMin;
    }

    public Integer getNumMax() {
        return numMax;
    }

    public void setNumMax(Integer numMax) {
        this.numMax = numMax;
    }

    public Integer getRadiusMin() {
        return radiusMin;
    }

    public void setRadiusMin(Integer radiusMin) {
        this.radiusMin = radiusMin;
    }

    public Integer getRadiusMax() {
        return radiusMax;
    }

    public void setRadiusMax(Integer radiusMax) {
        this.radiusMax = radiusMax;
    }

    public Integer getBubbleStrokeWidth() {
        return bubbleStrokeWidth;
    }

    public void setBubbleStrokeWidth(Integer bubbleStrokeWidth) {
        this.bubbleStrokeWidth = bubbleStrokeWidth;
    }
}

==> service_client-0.0.4-20220831.102351-56-sources.jar: com/northpool/service/config/style/style/style/Point.java <==
package com.northpool.service.config.style.style.style;

import java.util.Map;

public class Point {
    //点底图通用样式
    String type; //专题类型
    String labelType;//专题类型描述
    String texture;//散点符号

    //大部分样式包含的属性
    Double defaultRadius; //默认半径
    String fillColor;//散点填充颜色
    Integer fillAlpha;//散点透明度
    String strokeColor;//边框颜色
    Integer strokeAlpha;//边框透明度
    String field;//字段
    Integer maxWeight;//最大权重值
    Integer radius;// 用户输入半径
    Map<String, String> colorArr;//色带值


    //散点图包含的属性
    String fillType; //散点还是符号，区分类型
    Integer circleR;//散点半径
    Integer imageWidth;//符号宽
    Integer imageHeight;//符号高
    Integer originAngle;//旋转角度
    Integer ratoteField;//旋转字段


    //气泡图独有的属性
    Integer numMin;//最小范围
    Integer numMax;//最大范围
    Integer radiusMin;//最小半径
    Integer radiusMax;//最大半径
    Integer bubbleStrokeWidth;//边框宽

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getLabelType() {
        return labelType;
    }

    public void setLabelType(String labelType) {
        this.labelType = labelType;
    }

    public String getTexture() {
        return texture;
    }

    public void setTexture(String texture) {
        this.texture = texture;
    }

    public Double getDefaultRadius() {
        return defaultRadius;
    }

    public void setDefaultRadius(Double defaultRadius) {
        this.defaultRadius = defaultRadius;
    }

    public String getFillColor() {
        return fillColor;
    }

    public void setFillColor(String fillColor) {
        this.fillColor = fillColor;
    }

    public Integer getFillAlpha() {
        return fillAlpha;
    }

    public void setFillAlpha(Integer fillAlpha) {
        this.fillAlpha = fillAlpha;
    }

    public String getStrokeColor() {
        return strokeColor;
    }

    public void setStrokeColor(String strokeColor) {
        this.strokeColor = strokeColor;
    }

    public Integer getStrokeAlpha() {
        return strokeAlpha;
    }

    public void setStrokeAlpha(Integer strokeAlpha) {
        this.strokeAlpha = strokeAlpha;
    }

    public String getField() {
        return field;
    }

    public void setField(String field) {
        this.field = field;
    }

    public Integer getMaxWeight() {
        return maxWeight;
    }

    public void setMaxWeight(Integer maxWeight) {
        this.maxWeight = maxWeight;
    }

    public Integer getRadius() {
        return radius;
    }

    public void setRadius(Integer radius) {
        this.radius = radius;
    }


    public Map<String, String> getColorArr() {
        return colorArr;
    }

    public void setColorArr(Map<String, String> colorArr) {
        this.colorArr = colorArr;
    }

    public String getFillType() {
        return fillType;
    }

    public void setFillType(String fillType) {
        this.fillType = fillType;
    }

    public Integer getCircleR() {
        return circleR;
    }

    public void setCircleR(Integer circleR) {
        this.circleR = circleR;
    }

    public Integer getImageWidth() {
        return imageWidth;
    }

    public void setImageWidth(Integer imageWidth) {
        this.imageWidth = imageWidth;
    }

    public Integer getImageHeight() {
        return imageHeight;
    }

    public void setImageHeight(Integer imageHeight) {
        this.imageHeight = imageHeight;
    }

    public Integer getOriginAngle() {
        return originAngle;
    }

    public void setOriginAngle(Integer originAngle) {
        this.originAngle = originAngle;
    }

    public Integer getRatoteField() {
        return ratoteField;
    }

    public void setRatoteField(Integer ratoteField) {
        this.ratoteField = ratoteField;
    }

    public Integer getNumMin() {
        return numMin;
    }

    public void setNumMin(Integer numMin) {
        this.numMin = numMin;
    }

    public Integer getNumMax() {
        return numMax;
    }

    public void setNumMax(Integer numMax) {
        this.numMax = numMax;
    }

    public Integer getRadiusMin() {
        return radiusMin;
    }

    public void setRadiusMin(Integer radiusMin) {
        this.radiusMin = radiusMin;
    }

    public Integer getRadiusMax() {
        return radiusMax;
    }

    public void setRadiusMax(Integer radiusMax) {
        this.radiusMax = radiusMax;
    }

    public Integer getBubbleStrokeWidth() {
        return bubbleStrokeWidth;
    }

    public void setBubbleStrokeWidth(Integer bubbleStrokeWidth) {
        this.bubbleStrokeWidth = bubbleStrokeWidth;
    }
}
